@@ -193,12 +193,13 @@ class mysql(object):
 				with self.conn.cursor() as cur:
 					cur.execute(strs)
 					data=cur.fetchall() if is_query else cur.lastrowid
-					break
+				return data
 			except Exception as e:
 				if '2006' in str(e) or '2013' in str(e):
 					self.__init_connect__()
+				else:raise Exception(e)
 		# is_query or self.conn.commit()
-		return data
+		raise Exception('MYSQL:try 3 times connect,but error')
 	def add(self,dicts,table=None,ignore=False,duplicate=[]):
 		'''table is optional,dicts can be list or dict,duplicate should be list'''
 		if not isinstance(table,str):
@@ -221,7 +222,6 @@ class mysql(object):
 			for x in duplicate:
 				duplicate_str+=f' `{x}`=a.`{x}`,'
 			duplicate_str=duplicate_str[:-1]
-
 		return self.execute(f''' insert {ignore} `{table}`({key}) values {values[:-1]} {duplicate_str}''')
 	def update(self,where,data,table=None):
 		'''where can be str or dict'''
